@@ -4,6 +4,10 @@ test_that("describe_account_attributes", {
   expect_error(svc$describe_account_attributes(), NA)
 })
 
+test_that("describe_authentication_profiles", {
+  expect_error(svc$describe_authentication_profiles(), NA)
+})
+
 test_that("describe_cluster_db_revisions", {
   expect_error(svc$describe_cluster_db_revisions(), NA)
 })
@@ -32,6 +36,26 @@ test_that("describe_clusters", {
   expect_error(svc$describe_clusters(), NA)
 })
 
+test_that("describe_data_shares", {
+  expect_error(svc$describe_data_shares(), NA)
+})
+
+test_that("describe_data_shares_for_consumer", {
+  expect_error(svc$describe_data_shares_for_consumer(), NA)
+})
+
+test_that("describe_data_shares_for_producer", {
+  expect_error(svc$describe_data_shares_for_producer(), NA)
+})
+
+test_that("describe_endpoint_access", {
+  expect_error(svc$describe_endpoint_access(), NA)
+})
+
+test_that("describe_endpoint_authorization", {
+  expect_error(svc$describe_endpoint_authorization(), NA)
+})
+
 test_that("describe_event_categories", {
   expect_error(svc$describe_event_categories(), NA)
 })
@@ -56,6 +80,10 @@ test_that("describe_orderable_cluster_options", {
   expect_error(svc$describe_orderable_cluster_options(), NA)
 })
 
+test_that("describe_reserved_node_exchange_status", {
+  expect_error(svc$describe_reserved_node_exchange_status(), NA)
+})
+
 test_that("describe_reserved_node_offerings", {
   expect_error(svc$describe_reserved_node_offerings(), NA)
 })
